@@ -48,7 +48,7 @@ class MercurialServerTCMixin(object):
     @classmethod
     def create_mercurial_repo(cls, req, reponame, **kwargs):
         """ Create a mercurial repository """
-        repopath = cls.fs_repopath(reponame)
+        repopath = cls.fs_create_mercurial_repopath(reponame)
         return req.create_entity('Repository',
                                  title=unicode(reponame),
                                  type=u'mercurial',
@@ -97,7 +97,6 @@ class MercurialServerTCMixin(object):
                 data=Binary('admin public key'),
                 reverse_public_key=req.user)
         self.commit()
-        self.fs_create_mercurial_repopath('admin_repo')
         self.admin_user_repo = self.create_mercurial_repo(
                 req, 'admin_repo', hosted_by=self.server_config)
         self.commit()
